# [0.14.0](https://github.com/easytocloud/Mac-letterhead/compare/v0.13.9...v0.14.0) (2025-10-12)


### Features

* publish Mac-letterhead to MCP Registry ([35325c5](https://github.com/easytocloud/Mac-letterhead/commit/35325c5a1feda4a39af62ae248defc941585c571))

# Changelog

All notable changes to this project will be managed automatically by semantic-release.
